/*
Hello World-program. This program blinks a single led connected on PB0
of the ATMega. The frequency is about 1Hz.
*/

//The delay routines we're using have to know the frequency the CPU is running
//at. We can tell it by setting F_CPU. In this case, the CPU frequency is one 
//megahertz, the frequency an ATMega8 fresh from the factory runs at.
#define F_CPU 1000000

//This header is included to let the compiler understand the AVR registers, like
//PORTB/DDRB/...
#include <avr/io.h>
//This header is included so the compiler knows about the _delay_ms-routine
#include <util/delay.h>

//Convenience thingy: if we refer to LEDPIN from now on, the compiler will know
//we refer to PB0. PB0 actually is a #define in the included headers and
//evaluates to plain and simple '0'.
#define LEDPIN	PB0

//Main routine. The program starts here.
int main(void) {
	//Make the led pin into an output by setting the correct bit in the
	//DDRB (Data Direction for Port B) -register.
	DDRB=(1<<LEDPIN);
	
	//Make a loop which runs over and over and over again. This is what the
	//AVR will do as long as its running.
	while(1) { 
		//Let the AVR wait for 0.5 seconds
		_delay_ms(500);
		//Make the pin the led is connected to high
		PORTB|=(1<<LEDPIN);
		//Let the AVR wait for another 0.5 seconds
		_delay_ms(500);
		//Make the pin the led is connected to low again
		PORTB&=~(1<<LEDPIN);
	}
}

